##  Business Context
  * Identify business processes in the diagram, noting hierarchical relationships and process flows. Extract sub-processes that belong to larger business functions.
  * Identify business context elements arranged in tiers, noting parent-child relationships between processes, value streams, and products.
